@@ -1,6 +1,6 @@
 package Perl::Dist::WiX::Asset::DistBase;
 
-use 5.008001;
+use 5.010;
 use Moose;
 use File::Spec::Functions qw( catdir catfile );
 use Params::Util qw ( _INSTANCE );
@@ -8,9 +8,12 @@ use Params::Util qw ( _INSTANCE );
 require URI;
 require File::Spec::Unix;
 
-our $VERSION = '1.102_101';
+our $VERSION = '1.250_100';
 $VERSION =~ s/_//ms;
 
+# This is a base class, so routines in here would be technically "unused".
+## no critic(ProhibitUnusedPrivateSubroutines)
+
 sub _configure {
 	my $self    = shift;
 	my $buildpl = shift;
@@ -18,8 +21,8 @@ sub _configure {
 
 	$self->_trace_line( 2, "Configuring $name...\n" );
 	$buildpl
-	  ? $self->_perl( 'Build.PL',    @{ $self->_get_buildpl_param } )
-	  : $self->_perl( 'Makefile.PL', @{ $self->_get_makefilepl_param } );
+	  ? $self->_perl( 'Build.PL',    @{ $self->_get_buildpl_param() } )
+	  : $self->_perl( 'Makefile.PL', @{ $self->_get_makefilepl_param() } );
 
 	return;
 } ## end sub _configure
@@ -32,7 +35,7 @@ sub _install_distribution {
 	$self->_trace_line( 1, "Building $name...\n" );
 	$buildpl ? $self->_build() : $self->_make();
 
-	unless ( $self->_get_force() ) {
+	if ( not $self->_get_force() ) {
 		$self->_trace_line( 2, "Testing $name...\n" );
 		$buildpl ? $self->_build('test') : $self->_make('test');
 	}
@@ -49,11 +52,18 @@ sub _name_to_module {
 	my $self = shift;
 	my $dist = shift;
 
+	if ( not defined $dist ) {
+		PDWiX::Parameter->throw(
+			parameter => 'dist',
+			where     => '::Asset::DistBase->_name_to_module',
+		);
+	}
+
 	$self->_trace_line( 3, "Trying to get module name out of $dist\n" );
 
 #<<<
 	my ( $module ) = $dist =~ m{\A  # Start the string...
-					[A-Za-z/]*      # With a string of letters and slashes
+					[[:alpha:]/]*   # With a string of letters and slashes
 					/               # followed by a forward slash. 
 					(.*?)           # Then capture all characters, non-greedily 
 					-\d*[.]         # up to a dash, a sequence of digits, and then a period.
@@ -68,17 +78,19 @@ sub _module_build_installed {
 	my $self      = shift;
 	my $image_dir = $self->_get_image_dir();
 
-	my $perl_dir = catdir( $image_dir, 'perl' );
+	# Get all the directories to check.
 	my @dirs = (
 		catdir( $image_dir, qw( perl vendor lib Module ) ),
 		catdir( $image_dir, qw( perl site lib Module ) ),
 		catdir( $image_dir, qw( perl lib Module ) ),
 	);
 
+	# Return if we find Module::Build.
 	foreach my $dir (@dirs) {
 		return 1 if -f catfile( $dir, 'Build.pm' );
 	}
 
+	# We did not find it, so return that fact now.
 	return 0;
 } ## end sub _module_build_installed
 
@@ -90,7 +102,7 @@ sub _abs_uri {
 
 	# Get the base path
 	my $cpan = _INSTANCE( $self->_get_cpan(), 'URI' );
-	unless ($cpan) {
+	if ( not $cpan ) {
 		PDWiX::Parameter->throw("Did not get a cpan URI\n");
 	}
 
@@ -116,14 +128,12 @@ sub _DIST {
 	if ( not( defined $it and not ref $it ) ) {
 		return undef;
 	}
-	unless ( $it =~ q|^([A-Z]){2,}/| ) {
+	if ( $it !~ q|^([A-Z]){2,}/| ) {
 		return undef;
 	}
 	return $it;
 }
 
-1;
-
 no Moose;
 __PACKAGE__->meta->make_immutable;
 
@@ -137,17 +147,23 @@ __END__
 
 Perl::Dist::WiX::Asset::DistBase - Support routines for distribution assets.
 
+=head1 VERSION
+
+This document describes Perl::Dist::WiX::Asset::DistBase version 1.250_100.
+
 =head1 SYNOPSIS
 
 	# Not to be used independently.
 
 =head1 DESCRIPTION
 
-This module provides support routines that 
+This module provides private support routines that 
 L<Perl::Dist::WiX::Asset::Distribution|Perl::Dist::WiX::Asset::Distribution> 
 and L<Perl::Dist::WiX::Asset::DistFile|Perl::Dist::WiX::Asset::DistFile> 
 both use.
 
+There are no public methods defined by this module.
+
 =head1 SUPPORT
 
 Bugs should be reported via the CPAN bug tracker at
