@@ -8,7 +8,7 @@ Perl::Dist::WiX::Asset::DistFile - "Local Distribution" asset for a Win32 Perl
 
 =head1 VERSION
 
-This document describes Perl::Dist::WiX::Asset::DistFile version 1.200.
+This document describes Perl::Dist::WiX::Asset::DistFile version 1.250_100.
 
 =head1 SYNOPSIS
 
@@ -53,7 +53,7 @@ L<Perl::Dist::WiX::Role::Asset|Perl::Dist::WiX::Role::Asset>.
 
 =cut
 
-use 5.008001;
+use 5.010;
 use Moose;
 use MooseX::Types::Moose qw( Str Maybe Bool ArrayRef );
 use File::Spec::Functions qw( catdir catfile splitpath );
@@ -63,10 +63,10 @@ require URI;
 require File::Spec::Unix;
 require Perl::Dist::WiX::Exceptions;
 
-our $VERSION = '1.200';
+our $VERSION = '1.250_100';
 $VERSION =~ s/_//ms;
 
-with 'Perl::Dist::WiX::Role::Asset';
+with qw(Perl::Dist::WiX::Role::Asset WiX3::Role::Traceable);
 extends 'Perl::Dist::WiX::Asset::DistBase';
 
 =head1 METHODS
@@ -83,12 +83,17 @@ It inherits all the parameters described in the
 L<< Perl::Dist::WiX::Role::Asset->new|Perl::Dist::WiX::Role::Asset/new() >> 
 method documentation, and adds the additional parameters described below.
 
-=cut
+=head3 url
+
+The C<url> parameter is used as a location where the package can be 
+downloaded for 3 years, as required by the GNU Public License.
+
+This is used when generating release notes.
 
 =head3 mod_name
 
-The required C<mod_name> param is the name of the package for the purposes
-of identification.
+The required C<mod_name> parameter is the name of the package for the 
+purposes of identification.
 
 This should match the name of the main Perl module in the distribution, for 
 example, "File::Spec" or "Perl::Dist::WiX".
@@ -100,10 +105,11 @@ has mod_name => (
 	isa     => Maybe [Str],
 	reader  => 'get_name',
 	lazy    => 1,
-	default => sub { return $_[0]->_name_to_module(); },
+	default => sub { return $_[0]->_name_to_module( $_[0]->_get_file() ); },
 );
 
 
+
 =head3 force
 
 The optional boolean C<force> param allows you to specify that the tests
@@ -252,8 +258,10 @@ sub install {
 	my $dist_path = $filename;
 	$dist_path =~ s{[.] tar [.] gz}{}msx;   # Take off extensions.
 	$dist_path =~ s{[.] zip}{}msx;
-	$self->_add_to_distributions_installed($dist_path);
 	my $unpack_to = catdir( $self->_get_build_dir(), $dist_path );
+	my $dist_url = $self->_get_url();
+	$self->_add_to_distributions_installed($dist_url);
+	$self->trace_line( 0, "$dist_url\n" );
 
 	# Extract the tarball
 	if ( -d $unpack_to ) {
@@ -262,23 +270,23 @@ sub install {
 	}
 	$self->_trace_line( 4, "Unpacking to $unpack_to\n" );
 	$self->_extract( $path => $self->_get_build_dir() );
-	unless ( -d $unpack_to ) {
+	if ( not -d $unpack_to ) {
 		PDWiX->throw("Failed to extract $unpack_to\n");
 	}
 
 	# Check for a way to build the distribution.
 	my $buildpl    = ( -r catfile( $unpack_to, 'Build.PL' ) )    ? 1 : 0;
 	my $makefilepl = ( -r catfile( $unpack_to, 'Makefile.PL' ) ) ? 1 : 0;
-	unless ( $buildpl or $makefilepl ) {
+	if ( not $buildpl and not $makefilepl ) {
 		PDWiX->throw(
 			"Could not find Makefile.PL or Build.PL in $unpack_to\n");
 	}
 
 	# Build using Build.PL if we have one
 	# unless Module::Build is not installed.
-	unless ( $self->_module_build_installed() ) {
+	if ( not $self->_module_build_installed() ) {
 		$buildpl = 0;
-		unless ($makefilepl) {
+		if ( not $makefilepl ) {
 			PDWiX->throw( "Could not find Makefile.PL in $unpack_to"
 				  . " (too early for Build.PL)\n" );
 		}
