@@ -8,7 +8,7 @@ Perl::Dist::WiX::Asset::Distribution - "Perl Distribution" asset for a Win32 Per
 
 =head1 VERSION
 
-This document describes Perl::Dist::WiX::Asset::Distribution version 1.200.
+This document describes Perl::Dist::WiX::Asset::Distribution version 1.250_100.
 
 =head1 SYNOPSIS
 
@@ -47,7 +47,7 @@ C<install_distribution> method (and other things that call it).
 
 =cut
 
-use 5.008001;
+use 5.010;
 use Moose;
 use MooseX::Types::Moose qw( Str Bool ArrayRef Maybe );
 use File::Spec::Functions qw( catdir catfile );
@@ -56,7 +56,7 @@ use Params::Util qw( _INSTANCE );
 require File::Remove;
 require URI;
 
-our $VERSION = '1.200';
+our $VERSION = '1.250_100';
 $VERSION =~ s/_//ms;
 
 with 'Perl::Dist::WiX::Role::Asset';
@@ -286,7 +286,7 @@ sub BUILDARGS {
 			  . 'for Perl::Dist::WiX::Asset::Distribution' );
 	}
 
-	unless ( defined _INSTANCE( $args{parent}, 'Perl::Dist::WiX' ) ) {
+	if ( not defined _INSTANCE( $args{parent}, 'Perl::Dist::WiX' ) ) {
 		PDWiX::Parameter->throw(
 			parameter =>
 			  'parent: missing or not a Perl::Dist::WiX instance',
@@ -325,7 +325,7 @@ sub BUILDARGS {
 	my $path =
 	  File::Spec::Unix->catfile( 'authors', 'id', $one, "$one$two", $dist,
 	  );
-	$args{url} = URI->new_abs( $path, $args{parent}->cpan() )->as_string;
+	$args{url} = URI->new_abs( $path, $args{parent}->cpan() )->as_string();
 	$args{file} = $args{url};
 	$args{file} =~ s{.+/}{}ms;
 
@@ -394,11 +394,11 @@ sub install {
 
 	# Where will it get extracted to
 	my $dist_path = $name;
+	$self->_add_to_distributions_installed($dist_path);
 	$dist_path =~ s{[.] tar [.] gz}{}msx;   # Take off extensions.
 	$dist_path =~ s{[.] zip}{}msx;
 	$dist_path =~ s{.+\/}{}msx;        # Take off directories.
 	my $unpack_to = catdir( $build_dir, $dist_path );
-	$self->_add_to_distributions_installed($dist_path);
 
 	# Extract the tarball
 	if ( -d $unpack_to ) {
@@ -406,23 +406,23 @@ sub install {
 		File::Remove::remove( \1, $unpack_to );
 	}
 	$self->_extract( $tgz => $build_dir );
-	unless ( -d $unpack_to ) {
+	if ( not -d $unpack_to ) {
 		PDWiX->throw("Failed to extract $unpack_to\n");
 	}
 
 	my $buildpl    = ( -r catfile( $unpack_to, 'Build.PL' ) )    ? 1 : 0;
 	my $makefilepl = ( -r catfile( $unpack_to, 'Makefile.PL' ) ) ? 1 : 0;
 
-	unless ( $buildpl or $makefilepl ) {
+	if ( not $buildpl and not $makefilepl ) {
 		PDWiX->throw(
 			"Could not find Makefile.PL or Build.PL in $unpack_to\n");
 	}
 
 	# Build using Build.PL if we have one
 	# unless Module::Build is not installed.
-	unless ( $self->_module_build_installed() ) {
+	if ( not $self->_module_build_installed() ) {
 		$buildpl = 0;
-		unless ($makefilepl) {
+		if ( not $makefilepl ) {
 			PDWiX->throw( "Could not find Makefile.PL in $unpack_to"
 				  . " (too early for Build.PL)\n" );
 		}
