@@ -6,7 +6,7 @@ Perl::Dist::WiX::Asset::Module - Module asset for a Win32 Perl
 
 =head1 VERSION
 
-This document describes Perl::Dist::WiX::Asset::Module version 1.200_102.
+This document describes Perl::Dist::WiX::Asset::Module version 1.250_100.
 
 =head1 SYNOPSIS
 
@@ -25,16 +25,16 @@ This asset installs a module from CPAN.
 
 =cut
 
-use 5.008001;
+use 5.010;
 use Moose;
-use MooseX::Types::Moose qw( Str Bool );
+use MooseX::Types::Moose qw( Maybe Str Bool );
 use English qw( -no_match_vars );
 use File::Spec::Functions qw( catdir catfile );
 require Perl::Dist::WiX::Exceptions;
 require File::List::Object;
 require IO::File;
 
-our $VERSION = '1.200_102';
+our $VERSION = '1.250_100';
 $VERSION =~ s/_//ms;
 
 with 'Perl::Dist::WiX::Role::NonURLAsset';
@@ -90,7 +90,7 @@ object.
 
 
 has force => (
-	is      => 'ro',
+	is      => 'bare',
 	isa     => Bool,
 	reader  => '_get_force',
 	lazy    => 1,
@@ -111,7 +111,7 @@ This parameter defaults to true.
 
 
 has packlist => (
-	is      => 'ro',
+	is      => 'bare',
 	isa     => Bool,
 	reader  => '_get_packlist',
 	default => 1,
@@ -133,7 +133,7 @@ verification step.
 
 
 has assume_installed => (
-	is      => 'ro',
+	is      => 'bare',
 	isa     => Bool,
 	reader  => '_get_assume',
 	default => 0,
@@ -141,6 +141,23 @@ has assume_installed => (
 
 
 
+=head3 feature
+
+Specifies which feature the module is supposed to go in. 
+
+=cut
+
+
+
+has feature => (
+	is      => 'bare',
+	isa     => Maybe [Str],
+	reader  => 'get_feature',
+	default => undef,
+);
+
+
+
 =head2 install
 
 The install method installs the module described by the
@@ -166,7 +183,7 @@ sub install {
 	  :                                                        0;
 
 	# Verify the existence of perl.
-	unless ( $self->_get_bin_perl() ) {
+	if ( not $self->_get_bin_perl() ) {
 		PDWiX->throw(
 			'Cannot install CPAN modules yet, perl is not installed');
 	}
@@ -250,9 +267,11 @@ END_PERL
 	local $ENV{RELEASE_TESTING}     = undef;
 	$self->_run3( $self->_get_bin_perl(), $cpan_file )
 	  or PDWiX->throw('CPAN script execution failed');
-	PDWiX->throw(
-		"Failure detected installing $name, stopping [$CHILD_ERROR]")
-	  if $CHILD_ERROR;
+
+	if ($CHILD_ERROR) {
+		PDWiX->throw(
+			"Failure detected installing $name, stopping [$CHILD_ERROR]");
+	}
 
 	# Read in the dist file and add it the the list of
 	# distributions that were installed.
@@ -263,9 +282,6 @@ END_PERL
 		}
 		my $dist_info = <$fh>;
 		$fh->close;
-		$dist_info =~ s{[.] tar [.] gz}{}msx;   # Take off extensions.
-		$dist_info =~ s{[.] zip}{}msx;
-		$dist_info =~ s{.+\/}{}msx;    # Take off directories.
 		$self->_add_to_distributions_installed($dist_info);
 	} else {
 		$self->_trace_line( 0,
