@@ -8,7 +8,7 @@ Perl::Dist::WiX::Asset::PAR - "Binary .par package" asset for a Win32 Perl
 
 =head1 VERSION
 
-This document describes Perl::Dist::WiX::Asset::PAR version 1.200.
+This document describes Perl::Dist::WiX::Asset::PAR version 1.250_100.
 
 =head1 SYNOPSIS
 
@@ -30,7 +30,7 @@ B<Perl::Dist::WiX::Asset::PAR> is a data class that provides encapsulation
 and error checking for a "binary .par package" to be installed in a
 L<Perl::Dist::WiX|Perl::Dist::WiX>-based Perl distribution.
 
-It is normally created by the L<install_par|Perl::Dist::WiX::Installation/install_par> 
+It is normally created by the L<install_par|Perl::Dist::WiX::Mixin::Installation/install_par> 
 method of C<Perl::Dist::WiX> (and other things that call it). 
 
 The specification of the location to retrieve the package is done via
@@ -45,7 +45,7 @@ are installed.
 
 =cut
 
-use 5.008001;
+use 5.010;
 use Moose;
 use MooseX::Types::Moose qw( Str );
 use File::Spec::Functions qw( catdir catfile );
@@ -54,7 +54,7 @@ require SelectSaver;
 require PAR::Dist;
 require IO::String;
 
-our $VERSION = '1.200';
+our $VERSION = '1.250_100';
 $VERSION =~ s/_//ms;
 
 with 'Perl::Dist::WiX::Role::Asset';
@@ -76,7 +76,7 @@ parameter is provided.
 
 It inherits all the parameters described in the 
 L<Perl::Dist::WiX::Asset/new|Perl::Dist::WiX::Asset-E<gt>new()> 
-method documentation, and adds an additional parameter.
+method documentation, and adds two additional parameters.
 
 =head3 name
 
@@ -93,9 +93,24 @@ has name => (
 	required => 1,
 );
 
+=head3 name
+
+The required C<dist_info> parameter is the location of the source package 
+for the .par file, either as a URL (which should be accessible for 3 years) 
+or as a location on CPAN in the 'AUTHORID/dist-version.tar.gz' format.
+
+=cut
+
+has dist_info => (
+	is       => 'ro',
+	isa      => 'Str',
+	reader   => '_get_dist_info',
+	required => 1,
+);
+
 =head2 install
 
-The C<install> method retrieves the specified .par file and installs it71.
+The C<install> method retrieves the specified .par file and installs it.
 
 =cut
 
@@ -165,29 +180,7 @@ sub install {
 	$self->_trace_line( 2, $output );
 
 	# Get distribution name to add to what's installed.
-	if ( ( defined $url ) and ( $url =~ m{.*/([^/]*)\z}msx ) ) {
-		my $dist_info = $1;
-		$dist_info =~ s{[.] par}{}msx; # Take off .par extension.
-#<<<
-		if ($dist_info =~
-            m{\A(.*?)   # Grab anything that could be the name non-greedily, ...
-			-           # break at a dash,
-			([0-9._]*)  # then try to grab a version,
-			(?:-.*)?    # then discard anything else.
-			\z}msx
-		  )
-#>>>
-		{
-			my ( $dist_name, $dist_ver ) = ( $1, $2 );
-			$dist_info = "${dist_name}-${dist_ver}";
-			$self->_add_to_distributions_installed($dist_info);
-		} else {
-			$self->_trace_line( 1, <<"EOF");
-Could not parse name of .par to determine name and version.
-Source: $dist_info
-EOF
-		}
-	} ## end if ( ( defined $url ) ...)
+	$self->_add_to_distributions_installed( $self->_get_dist_info() );
 
 	# Read in the .packlist and return it.
 	my $filelist =
