@@ -1,43 +1,15 @@
 package Perl::Dist::WiX::Tag::Icon;
 
-#####################################################################
-# Perl::Dist::WiX::Tag::Icon - Extends <Icon> tags to make them searchable
-# easily by Perl::Dist::WiX::IconArray.
-#
-# Copyright 2009 Curtis Jewell
-#
-# License is the same as perl. See Wix.pm for details.
-#
-#<<<
-use 5.008001;
-use Moose;
-use MooseX::Types::Moose qw( Str );
-
-our $VERSION = '1.101_001';
-$VERSION =~ s/_//ms;
-
-extends 'WiX3::XML::Icon';
-
-has target_type => (
-	is => 'bare',
-	isa => Str,
-	reader => 'get_target_type',
-	required => 1,
-);
-
-no Moose;
-__PACKAGE__->meta->make_immutable();
-
-1;
-
-__END__
-
 =pod
 
 =head1 NAME
 
 Perl::Dist::WiX::Tag::Icon - <Icon> tag that stores its type of target.
 
+=head1 VERSION
+
+This document describes Perl::Dist::WiX::Tag::Icon version 1.250_100.
+
 =head1 SYNOPSIS
 
 	my $tag = Perl::Dist::WiX::Tag::Icon->new(
@@ -48,33 +20,63 @@ Perl::Dist::WiX::Tag::Icon - <Icon> tag that stores its type of target.
 
 =head1 DESCRIPTION
 
-This is an XML tag that specifies an icon that is used in a Perl::Dist::WiX 
-based distribution.
+This is an XML tag that specifies an icon that is used in a 
+L<Perl::Dist::WiX|Perl::Dist::WiX>-based distribution.
+
+=cut
+
+use 5.010;
+use Moose;
+use MooseX::Types::Moose qw( Str );
+
+our $VERSION = '1.250_100';
+$VERSION =~ s/_//ms;
+
+extends 'WiX3::XML::Icon';
 
 =head1 METHODS
 
-This class is a L<WiX3::XML::Icon> and inherits its API, so only additional 
-API is documented here.
+This class is a L<WiX3::XML::Icon|WiX3::XML::Icon> and inherits its API, 
+so only additional API is documented here.
 
 =head2 new
 
 The C<new> constructor takes a series of parameters, validates then
-and returns a new B<Perl::Dist::WiX::Tag::Icon> object.
+and returns a new C<Perl::Dist::WiX::Tag::Icon> object.
 
 If an error occurs, it throws an exception.
 
 It inherits all the parameters described in the 
-L<WiX3::XML::Icon> C<new> method documentation, and adds one additional 
-parameter.
+L<< WiX3::XML::Icon->new()|WiX3::XML::Icon/new >> method documentation, 
+and adds one additional parameter.
 
-=over 4
+=head3 target_type
 
-=item target_type
+The required string C<target_type> parameter stores the extension of the 
+target of a shortcut icon, or 'msi' if this is the icon for the msi.
 
-The required string C<target_type> param stores the extension of the target 
-of a shortcut icon, or 'msi' if this is the icon for the msi.
+=cut
 
-=back
+=head2 get_target_type
+
+The method C<get_target_type> param retrieves the extension of the target 
+of the shortcut icon that was stored in the object.
+
+=cut
+
+has target_type => (
+	is       => 'bare',
+	isa      => Str,
+	reader   => 'get_target_type',
+	required => 1,
+);
+
+no Moose;
+__PACKAGE__->meta->make_immutable();
+
+1;
+
+__END__
 
 =head1 SUPPORT
 
@@ -90,12 +92,12 @@ Curtis Jewell E<lt>csjewell@cpan.orgE<gt>
 
 =head1 SEE ALSO
 
-L<Perl::Dist::WiX>, 
+L<Perl::Dist::WiX|Perl::Dist::WiX>, 
 L<http://wix.sourceforge.net/manual-wix3/wix_xsd_icon.htm>,
 
 =head1 COPYRIGHT
 
-Copyright 2009 Curtis Jewell.
+Copyright 2009 - 2010 Curtis Jewell.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
